Describes the class of one or more variables across cohorts and indicates differences
Source:R/class-discrepancy.R
dh.classDiscrepancy.RdEither through using ds.dataFrameFill, or due to mistakes in uploading data, the same variable may have a different class across cohorts. This can create problems as many DataSHIELD functions require the input variable to have the same class in all studies. This function produces a tibble showing the class of each variable.
Value
A tibble with columns for each variable and rows for each cohort describing the class of the variable, with an additional column 'discrepancy' summarising whether there are differences between cohorts.
See also
Other descriptive functions:
dh.anyData(),
dh.createTableOne(),
dh.getStats(),
dh.lmTab(),
dh.meanByGroup()