Produces descriptive statistics based on repeated measures data which it would be useful to report in papers.
Source:R/get-rm-stats.R
dh.getRmStats.RdProduces descriptive statistics based on repeated measures data which it would be useful to report in papers.
Value
a tibble containing the following columns:
min_age: 5th percentile of age max_age: 95th percentile of age n_obs: total number of observations in data n_participants: total number of unique participants n_meas_5: 5th percentile of measurements per individual n_meas_med: median number of measurements per individual n_meas_95: 95th percentile of measurements per individual