![[Deprecated]](figures/lifecycle-deprecated.svg)
This was a wrapper around ds.rm intended to allow the removal of multiple objects
in one call. It was deprecated because we realised that this was already possible with
ds.rm()
Usage
dh.tidyEnv(obj = NULL, type = NULL, conns = NULL)
Arguments
- obj
Server-side objects that you want to either keep or remove.
- type
Either "remove" to remove objects specified in obj or "keep" to
keep objects specified in obj and remove everything else.
- conns
DataSHIELD connections object.
Value
None. Objects are removed from the server-side environnment.